==> final-form-4.18.4.tgz: package/README.md <==
💰 **Hey there! Do you fancy yourself a javascript expert? [Take this quiz](https://triplebyte.com/a/V6j0KPS/ff) and get offers from top tech companies!** 💰

---

# 🏁 Final Form

[![Final Form](banner.png)](https://final-form.org)

[![Backers on Open Collective](https://opencollective.com/final-form/backers/badge.svg)](#backers)
[![Sponsors on Open Collective](https://opencollective.com/final-form/sponsors/badge.svg)](#sponsors)
[![NPM Version](https://img.shields.io/npm/v/final-form.svg?style=flat)](https://www.npmjs.com/package/final-form)
[![NPM Downloads](https://img.shields.io/npm/dm/final-form.svg?style=flat)](https://npm-stat.com/charts.html?package=final-form)
[![Build Status](https://travis-ci.org/final-form/final-form.svg?branch=master)](https://travis-ci.org/final-form/final-form)
[![codecov.io](https://codecov.io/gh/final-form/final-form/branch/master/graph/badge.svg)](https://codecov.io/gh/final-form/final-form)
[![styled with prettier](https://img.shields.io/badge/styled_with-prettier-ff69b4.svg)](https://github.com/prettier/prettier)

✅ **Zero** dependencies [\*](#zero-dependencies)

✅ Framework agnostic

✅ Opt-in subscriptions - only update on the state you need!

✅ 💥 [**5.1k gzipped**](https://bundlephobia.com/result?p=final-form) 💥

---

## 💬 [Give Feedback on Final Form](https://goo.gl/forms/dxdfxKNy64DLb99z2) 💬

In the interest of making 🏁 Final Form the best library it can be, we'd love your thoughts and feedback.

[Take a quick survey](https://goo.gl/forms/dxdfxKNy64DLb99z2).

---

## [Get Started](https://final-form.org/docs/final-form/getting-started)

## [Philosophy](https://final-form.org/docs/final-form/philosophy)

## [Examples](https://final-form.org/docs/final-form/examples)

## [API](https://final-form.org/docs/final-form/api)

## [Companion Libraries](https://final-form.org/docs/final-form/companion-libraries)

## [Who's using Final Form?](https://final-form.org/users)

==> final-form-4.18.7.tgz: package/README.md <==
<p align="center">
<a href="https://codefund.io/properties/556/visit-sponsor">
<img src="https://codefund.io/properties/556/sponsor" />
</a>
</p>

💰 **Hey there! Do you fancy yourself a javascript expert? [Take this quiz](https://triplebyte.com/a/V6j0KPS/ff) and get offers from top tech companies!** 💰

---

# 🏁 Final Form

[![Final Form](banner.png)](https://final-form.org)

[![Backers on Open Collective](https://opencollective.com/final-form/backers/badge.svg)](#backers)
[![Sponsors on Open Collective](https://opencollective.com/final-form/sponsors/badge.svg)](#sponsors)
[![NPM Version](https://img.shields.io/npm/v/final-form.svg?style=flat)](https://www.npmjs.com/package/final-form)
[![NPM Downloads](https://img.shields.io/npm/dm/final-form.svg?style=flat)](https://npm-stat.com/charts.html?package=final-form)
[![Build Status](https://travis-ci.org/final-form/final-form.svg?branch=master)](https://travis-ci.org/final-form/final-form)
[![codecov.io](https://codecov.io/gh/final-form/final-form/branch/master/graph/badge.svg)](https://codecov.io/gh/final-form/final-form)
[![styled with prettier](https://img.shields.io/badge/styled_with-prettier-ff69b4.svg)](https://github.com/prettier/prettier)

✅ **Zero** dependencies

✅ Framework agnostic

✅ Opt-in subscriptions - only update on the state you need!

✅ 💥 [**5.1k gzipped**](https://bundlephobia.com/result?p=final-form) 💥

---

## 💬 [Give Feedback on Final Form](https://goo.gl/forms/dxdfxKNy64DLb99z2) 💬

In the interest of making 🏁 Final Form the best library it can be, we'd love your thoughts and feedback.

[Take a quick survey](https://goo.gl/forms/dxdfxKNy64DLb99z2).

---

## [Get Started](https://final-form.org/docs/final-form/getting-started)

## [Philosophy](https://final-form.org/docs/final-form/philosophy)

## [Examples](https://final-form.org/docs/final-form/examples)

## [API](https://final-form.org/docs/final-form/api)

## [Companion Libraries](https://final-form.org/docs/final-form/companion-libraries)

## [Who's using Final Form?](https://final-form.org/users)
